@@ -1,7 +1,7 @@
 /*
  * Filename routines for HTMLDOC, a HTML document processing program.
  *
- * Copyright © 2011-2019 by Michael R Sweet.
+ * Copyright © 2011-2023 by Michael R Sweet.
  * Copyright © 1997-2010 by Easy Software Products.  All rights reserved.
  *
  * This program is free software.  Distribution and use rights are outlined in
@@ -13,7 +13,7 @@
  */
 
 #include "file.h"
-#include "http.h"
+#include <cups/http.h>
 #include "progress.h"
 #include "debug.h"
 
@@ -304,6 +304,7 @@ const char *			/* O - File extension */
 file_extension(const char *s)	/* I - Filename or URL */
 {
   const char	*extension;	/* Pointer to directory separator */
+  char		*bufptr;	/* Pointer into buffer */
   static char	buf[1024];	/* Buffer for files with targets */
 
 
@@ -334,7 +335,8 @@ file_extension(const char *s)	/* I - Filename or URL */
 
   strlcpy(buf, extension, sizeof(buf));
 
-  *(char *)strchr(buf, '#') = '\0';
+  if ((bufptr = strchr(buf, '#')) != NULL)
+    *bufptr = '\0';
 
   return (buf);
 }
@@ -622,11 +624,13 @@ file_find(const char *path,		/* I - Path "dir;dir;dir" */
   */
 
   for (i = 0; i < (int)web_files; i ++)
+  {
     if (strcmp(s, web_cache[i].name) == 0)
     {
       DEBUG_printf(("file_find: Returning cache file \"%s\"!\n", s));
-      return (s);
+      return (web_cache[i].name);
     }
+  }
 
   DEBUG_printf(("file_find: \"%s\" not in web cache of %d files...\n", s, (int)web_files));
 
@@ -635,11 +639,14 @@ file_find(const char *path,		/* I - Path "dir;dir;dir" */
   */
 
   if (strchr(s, '%') == NULL)
+  {
     strlcpy(basename, s, sizeof(basename));
+  }
   else
   {
     for (sptr = s, temp = basename;
 	 *sptr && temp < (basename + sizeof(basename) - 1);)
+    {
       if (*sptr == '%' && isxdigit(sptr[1]) && isxdigit(sptr[2]))
       {
        /*
@@ -662,6 +669,7 @@ file_find(const char *path,		/* I - Path "dir;dir;dir" */
       }
       else
 	*temp++ = *sptr++;
+    }
 
     *temp = '\0';
   }
@@ -916,7 +924,9 @@ file_localize(const char *filename,	/* I - Filename */
 const char *			/* O - Method string ("http", "ftp", etc.) */
 file_method(const char *s)	/* I - Filename or URL */
 {
-  if (strncmp(s, "http:", 5) == 0)
+  if (strncmp(s, "data:", 5) == 0)
+    return ("data");
+  else if (strncmp(s, "http:", 5) == 0)
     return ("http");
   else if (strncmp(s, "https:", 6) == 0)
     return ("https");
@@ -1000,8 +1010,15 @@ file_rlookup(const char *filename)	/* I - Filename */
 
 
   for (i = web_files, wc = web_cache; i > 0; i --, wc ++)
+  {
     if (!strcmp(wc->name, filename))
-      return (wc->url);
+    {
+      if (!strncmp(wc->url, "data:", 5))
+        return ("data URL");
+      else
+        return (wc->url);
+    }
+  }
 
   return (filename);
 }
