@@ -1,7 +1,7 @@
 /*
  * Main entry for HTMLDOC, a HTML document processing program.
  *
- * Copyright 2011-2020 by Michael R Sweet.
+ * Copyright 2011-2023 by Michael R Sweet.
  * Copyright 1997-2010 by Easy Software Products.  All rights reserved.
  *
  * This program is free software.  Distribution and use rights are outlined in
@@ -15,7 +15,7 @@
 #define _HTMLDOC_CXX_
 #include "htmldoc.h"
 #include "markdown.h"
-#include "http.h"
+#include <cups/http.h>
 #include <ctype.h>
 #include <fcntl.h>
 
@@ -980,6 +980,14 @@ main(int  argc,				/* I - Number of command-line arguments */
     }
     else if (compare_strings(argv[i], "--portrait", 4) == 0)
       Landscape = 0;
+    else if (compare_strings(argv[i], "--pre-indent", 5) == 0)
+    {
+      i ++;
+      if (i < argc)
+        PreIndent = get_measurement(argv[i]);
+      else
+        usage(argv[i - 1]);
+    }
     else if (compare_strings(argv[i], "--proxy", 4) == 0)
     {
       i ++;
@@ -1271,9 +1279,16 @@ main(int  argc,				/* I - Number of command-line arguments */
   */
 
   if (OutputType == OUTPUT_BOOK && TocLevels > 0)
+  {
     toc = toc_build(document);
+  }
   else
+  {
+    if (TocNumbers)
+      htmlDeleteTree(toc_build(document));
+
     toc = NULL;
+  }
 
   htmlDebugStats("Table of Contents Tree", toc);
 
@@ -2164,6 +2179,8 @@ parse_options(const char   *line,	// I - Options from book file
       PageTop = get_measurement(temp2);
     else if (strcmp(temp, "--bottom") == 0)
       PageBottom = get_measurement(temp2);
+    else if (strcmp(temp, "--pre-indent") == 0)
+      PreIndent = get_measurement(temp2);
     else if (strcmp(temp, "--header") == 0)
       get_format(temp2, Header);
     else if (strcmp(temp, "--header1") == 0)
@@ -2600,7 +2617,7 @@ usage(const char *arg)			// I - Bad argument string
   if (CGIMode)
     puts("Content-Type: text/plain\r\n\r");
 
-  puts("HTMLDOC Version " SVERSION " Copyright 2011-2020 by Michael R Sweet.");
+  puts("HTMLDOC Version " SVERSION " Copyright 2011-2022 by Michael R Sweet.");
   puts("HTMLDOC is provided under the terms of the GNU General Public License and");
   puts("comes with absolutely no warranty.  This software is based in part on the work");
   puts("of the Independent JPEG Group.");
