@@ -2,7 +2,7 @@
  * Separated HTML export functions for HTMLDOC, a HTML document processing
  * program.
  *
- * Copyright 2011-2019 by Michael R Sweet.
+ * Copyright 2011-2021 by Michael R Sweet.
  * Copyright 1997-2010 by Easy Software Products.  All rights reserved.
  *
  * This program is free software.  Distribution and use rights are outlined in
@@ -285,7 +285,7 @@ write_header(FILE   **out,	/* IO - Output file */
   fprintf(*out, "H6 { font-family: %s; }\n", families[_htmlHeadingFont]);
   fputs("SUB { font-size: smaller; }\n", *out);
   fputs("SUP { font-size: smaller; }\n", *out);
-  fputs("PRE { font-family: monospace; margin-left: 36pt; }\n", *out);
+  fprintf(*out, "PRE { font-family: monospace; margin-left: %dpt; }\n", PreIndent);
 
   if (!LinkStyle)
     fputs("A { text-decoration: none; }\n", *out);
@@ -455,10 +455,11 @@ write_title(FILE  *out,		/* I - Output file */
     {
       image_t *img = image_load(TitleImage, !OutputColor);
 
-      fprintf(out, "<IMG SRC=\"%s\" WIDTH=\"%d\" HEIGHT=\"%d\" "
-	           "ALT=\"%s\"><BR>\n",
-              file_basename((char *)TitleImage), img->width, img->height,
-	      title ? (char *)title : "");
+      if (img)
+	fprintf(out, "<IMG SRC=\"%s\" WIDTH=\"%d\" HEIGHT=\"%d\" "
+		     "ALT=\"%s\"><BR>\n",
+		file_basename((char *)TitleImage), img->width, img->height,
+		title ? (char *)title : "");
     }
 
     if (title != NULL)
@@ -591,7 +592,7 @@ write_node(FILE   *out,		/* I - Output file */
           for (ptr = t->data; *ptr; ptr ++)
             fputs((char *)iso8859(*ptr), out);
 
-	  if (t->data[strlen((char *)t->data) - 1] == '\n')
+	  if (t->data[0] && t->data[strlen((char *)t->data) - 1] == '\n')
             col = 0;
 	  else
             col += strlen((char *)t->data);
@@ -915,7 +916,10 @@ add_heading(tree_t *t)			// I - Heading node
   // Start by getting the heading text...
   heading = htmlGetText(t->child);
   if (!heading || !*heading)
+  {
+    free(heading);
     return;				// Nothing to do!
+  }
 
   // Sanitize the text...
   for (ptr = heading; *ptr;)
