@@ -2,7 +2,7 @@
  * Progress function definitions for HTMLDOC, a HTML document
  * processing program.
  *
- * Copyright 2011 by Michael R Sweet.
+ * Copyright 2011-2019 by Michael R Sweet.
  * Copyright 1997-2010 by Easy Software Products.  All rights reserved.
  *
  * This program is free software.  Distribution and use rights are outlined in
@@ -48,9 +48,17 @@ typedef enum
  * Prototypes...
  */
 
-extern void	progress_error(HDerror error, const char *format, ...);
+extern void	progress_error(HDerror error, const char *format, ...)
+#    ifdef __GNUC__
+__attribute__ ((__format__ (__printf__, 2, 3)))
+#    endif /* __GNUC__ */
+;
 extern void	progress_hide(void);
-extern void	progress_show(const char *format, ...);
+extern void	progress_show(const char *format, ...)
+#    ifdef __GNUC__
+__attribute__ ((__format__ (__printf__, 1, 2)))
+#    endif /* __GNUC__ */
+;
 extern void	progress_update(int percent);
 
 #  ifdef __cplusplus
